#
# spec file for package telepathy-farstream
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           telepathy-farstream
Version:        0.6.2
Release:        4.6
Summary:        Telepathy library to handle Call channels
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            http://telepathy.freedesktop.org/
Source0:        http://telepathy.freedesktop.org/releases/telepathy-farstream/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(farstream-0.2)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gobject-2.0) >= 2.32
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(telepathy-glib) >= 0.21

%description
Telepathy Farstream is a Telepathy client library that uses Farsight2
to handle Call channels.

%package -n libtelepathy-farstream3
Summary:        Telepathy library to handle Call channels
# There used to be python bindings for this library, but this now
# achieved with introspection. Since there's no guarantee the
# bindings will still work with this version, we obsolete them
Group:          System/Libraries
Obsoletes:      python-tpfarstream < %{version}

%description -n libtelepathy-farstream3
Telepathy Farstream is a Telepathy client library that uses Farsight2
to handle Call channels.

%package -n typelib-1_0-TelepathyFarstream-0_6
Summary:        Introspection bindings for the Telepathy Call channel handling library
Group:          System/Libraries

%description -n typelib-1_0-TelepathyFarstream-0_6
Telepathy Farstream is a Telepathy client library that uses Farsight2
to handle Call channels.

%package devel
Summary:        Development files for the Telepathy Call channel handling library
Group:          Development/Languages/C and C++
Requires:       libtelepathy-farstream3 = %{version}
Requires:       typelib-1_0-TelepathyFarstream-0_6 = %{version}

%description devel
Telepathy Farstream is a Telepathy client library that uses Farsight2
to handle Call channels.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libtelepathy-farstream3 -p /sbin/ldconfig
%postun -n libtelepathy-farstream3 -p /sbin/ldconfig

%files -n libtelepathy-farstream3
%license COPYING
%doc ChangeLog NEWS README
%{_libdir}/libtelepathy-farstream.so.*

%files -n typelib-1_0-TelepathyFarstream-0_6
%{_libdir}/girepository-1.0/TelepathyFarstream-0.6.typelib

%files devel
%dir %{_includedir}/telepathy-1.0
%{_includedir}/telepathy-1.0/telepathy-farstream/
%{_libdir}/pkgconfig/telepathy-farstream.pc
%{_libdir}/libtelepathy-farstream.so
%doc %{_datadir}/gtk-doc/
%{_datadir}/gir-1.0/TelepathyFarstream-0.6.gir

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Mon Mar  5 2018 jengelh@inai.de
- Update summaries, fix SRPM group.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf: provide multi-arch packages.
* Mon Aug 25 2014 zaitor@opensuse.org
- Update to version 0.6.2:
  + Fixes: call-stream: add mising 'break' in switch block
    (fdo#79006).
- Drop tp-fs-add-mising-break-in-switch-block.patch: Fixed
  upstream.
* Sun Aug 10 2014 zaitor@opensuse.org
- Add tp-fs-add-mising-break-in-switch-block.patch, call-stream:
  add mising 'break' in switch block (fdo#79006). Patch from
  upstream git.
* Sat Mar  8 2014 dimstar@opensuse.org
- Update to version 0.6.1.:
  + Fix build with newer telepathy-glib branches.
  + Fix build with automake 1.13.
  + Improve configure.ac with AS_IF.
  + Fix calls with standard ICE-UDP (against Gajim).
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 0.6.0:
  + Port to the final Farstream 0.2 API.
* Fri Sep 14 2012 dimstar@opensuse.org
- Update to version 0.5.0:
  + Port to GStreamer 1.0 and Farstream 0.2
  + Set RemoteContact when accepting & updating media descriptions.
- Drop telepathy-farstream-gst10.patch: fixed upstream.
- Rename telepathy-farstream2 to telepathy-farstream3, following
  upstreams soname bump.
* Tue Sep 11 2012 dimstar@opensuse.org
- Add telepathy-farstream-gst10.patch: Change pkg-config
  dependencies to gstreamer-1.0 and farstream-0.2.
* Tue Sep 11 2012 dimstar@opensuse.org
- Update to version 0.4.999.1 (git snapshot, commit id 9e626b)
  + Port to GStreamer 1.0
  + Depend on farstream-0.2
  + Drop static python bindings in favor of gobject-introspection
    based ones
- Change pkgconfig(farstream-0.1) BuildRequires to
  pkgconfig(farstream-0.2), following the port to GStreamer 1.0
- Remove static python bindings:
  + Drop python-tpfarstream subpackage
  + Drop pkgconfig(gst-python-0.10) and pkgconfig(pygobject-2.0)
    BuildRequires.
  + Add a Obsoletes for python-tpfarstream to
    libtelepathy-farstream2 since it's unclear the old bindings
    still work with this version.
- Add gobject-introspection based bindings:
  + Add pkgconfig(gobject-introspection-1.0) BuildRequires.
  + Create typelib-1_0-TelepathyFarstream-0_6 sub package
  + Require typelib-1_0-TelepathyFarstream-0_6 from the -devel
    package.
* Thu Apr  5 2012 vuntz@opensuse.org
- Update to version 0.4.0:
  + No major change since 0.2.3.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 0.2.3:
  + Fix various bugs.
  + Improve debug messages.
  + Improve GI annotations.
  + Use the generic marshallers.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 0.2.2:
  + Allow an Endpoint to be removed so as it work with Rakia call
    transfers
  + Ignore glib post-2.26 deprecations
  + added a tf_channel_new_finish() function
  + Misc bug fixes
- Add explicit pkgconfig(glib-2.0) and pkgconfig(gobject-2.0)
  BuildRequires. They are being pulled in by others already, but
  having explicit BuildRequires allows us to require them
  versioned.
- Rename telepathy-farstream1 to telepathy-farstream2, following
  the upstream soname change.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 0.2.1:
  + Now use Call1 as well as Streamed Media
  + Now requires Farstream and telepathy-glib 0.17.5
- Change pkgconfig(farsight2-0.10) BuildRequires to
  pkgconfig(farstream-0.1), following the move to Farstream.
- Rename libtelepathy-farstream0 to libtelepathy-farstream1,
  following upstream soversion bump.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.1.2:
  + Fix linking with ld --as-needed
  + Add AudioControl support
  + Respond to farsight-negotiate events
- Drop telepathy-farstream-link-issue.patch: fixed upstream.
- Remove call to autoreconf, as we don't carry any patch anymore.
* Fri Sep  2 2011 vuntz@opensuse.org
- Add telepathy-farstream-link-issue.patch: fix linking issue.
- Add call to autoreconf, needed for patch above.
* Tue Jul 26 2011 vuntz@opensuse.org
- Initial package of telepathy-farstream (version 0.1.1).
